function genPlotScalarBVP(bvp,info,U,stitle,verbose)
  Th=bvp.Th;
  is_solex=false;
  if isfield(info,'solex') && ~isempty(info.solex)
      Uex=Th.eval(info.solex);
      E=abs(U-Uex);
      is_solex=true;
  end
  if verbose>=2, fprintf('*** Graphic representations\n');end
  close all
  if Th.d==2
    figure(1)
    Th.plotmesh('color','LightGray')
    hold on
    Th.plotmesh('inlegend',true,'d',1,'LineWidth',2)
    legend('show')
    axis off,axis image
    title(sprintf('%s, Mesh',stitle))

    figure(2)
    Th.plot(U)
    axis off,axis image
    colorbar
    shading interp
    title(sprintf('%s, P1-FEM solution',stitle))

    if is_solex
      figure(3)
      colormap('jet')
      Th.plot(E)
      axis off,axis image
      colorbar
      shading interp
      title(sprintf('%s, P1-FEM error',stitle))
    end
  elseif Th.d==3
    figure(1)
    Th.plotmesh('inlegend',true)
    legend('show')
    axis off,axis image
    title(sprintf('%s, Mesh',stitle))
    figure(2)
    Th.plotmesh('inlegend',true,'d',2)
    legend('show')
    axis off,axis image
    title(sprintf('%s, Mesh boundaries',stitle))
    
    MidPoint=0.5*(Th.bbox(2:2:end)-Th.bbox(1:2:end));
    P=[fc_tools.graphics.PlaneCoefs(MidPoint,[1 0 0]); ...
       fc_tools.graphics.PlaneCoefs(MidPoint,[0 1 0]); ...
       fc_tools.graphics.PlaneCoefs(MidPoint,[0 0 1])];
    
    figure(3)
    Th.plot(U)
    axis image;axis off;colorbar
    title(sprintf('%s, P1-FEM solution',stitle))
    figure(4)
    Th.slice(U,P)%, 'FaceColor','interp', 'EdgeColor','none')
    hold on
    Th.sliceiso(U,P,'niso',10,'Color','w')
    axis image;axis off;colorbar
    title(sprintf('%s, P1-FEM solution',stitle))
    
    if is_solex
      figure(5)
      colormap('jet')
      Th.plot(E)
      axis image;axis off;colorbar
      title(sprintf('%s, P1-FEM error',stitle))
      figure(6)
      colormap('jet')
      Th.slice(E,P)%, 'FaceColor','interp', 'EdgeColor','none')
      hold on
      Th.sliceiso(E,P,'niso',10,'Color','w')
      axis image;axis off;colorbar
      title(sprintf('%s, P1-FEM error',stitle))
    end
  else
    P = mfilename();
    fprintf('In function %s: not yet implemented for Th.d=%d\n',P,Th.d);
    P = mfilename('fullpath');
    fprintf('in file :\n  %s\n',P);
  end
  fc_tools.graphics.monitors.autoGrid('covers',0.9);
end
